# Change Log

The format is based on [Keep a Changelog](http://keepachangelog.com/).

## [Unreleased]
### Added
- ...

### Changed
- ...

## [0.1.6] - 2017-02-06
### Added
- [infra] package renamed from vcs_extras->vci

## [0.1.5] - 2017-02-05
### Added
- [infra] version option added

### Changed
- [find] bugfix lookup from method calls

## [0.1.4] - 2017-02-01
### Changed
- [config, list] --no-colour option added

## [0.1.3] - 2017-02-01
### Changed
- [find,list] added --index override functionality

## [0.1.2] - 2017-01-24
### Changed
- [find] library methods for retrieving the yaml contents
- [list] catch and log errors when the index cannot be found

## [0.1.1] - 2017-01-23
### Added
- [docs] changelog added

## [0.1.0] - 2017-01-23
### Added
- [find] parse the index and generate the .repos text to feed to vcs
- [list] list the contents of the index
- [config] set, set-default or just display the current index url

[Unreleased]: https://github.com/stonier/vci/compare/0.1.5...HEAD
[0.1.5]: https://github.com/stonier/vci/compare/0.1.4...0.1.5
[0.1.4]: https://github.com/stonier/vci/compare/0.1.3...0.1.4
[0.1.3]: https://github.com/stonier/vci/compare/0.1.2...0.1.3
[0.1.2]: https://github.com/stonier/vci/compare/0.1.1...0.1.2
[0.1.1]: https://github.com/stonier/vci/compare/0.1.0...0.1.1
[0.1.0]: https://github.com/stonier/vci/compare/c838ad46f0ffde6a9d030cbf0c91653bf5fd48e6...0.1.0
